Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the garm-operator v1alpha1 API group +kubebuilder:object:generate=true +groupName=garm-operator.mercedes-benz.com
Index ¶
- Variables
- type Enterprise
- func (in *Enterprise) DeepCopy() *Enterprise
- func (in *Enterprise) DeepCopyInto(out *Enterprise)
- func (in *Enterprise) DeepCopyObject() runtime.Object
- func (e *Enterprise) GetCredentialsName() string
- func (e *Enterprise) GetID() string
- func (e *Enterprise) GetKind() string
- func (e *Enterprise) GetName() string
- func (e *Enterprise) GetPoolManagerFailureReason() string
- func (e *Enterprise) GetPoolManagerIsRunning() bool
- type EnterpriseList
- type EnterpriseSpec
- type EnterpriseStatus
- type GitHubScope
- type GitHubScopeKind
- type Image
- func (in *Image) DeepCopy() *Image
- func (in *Image) DeepCopyInto(out *Image)
- func (in *Image) DeepCopyObject() runtime.Object
- func (i *Image) SetupWebhookWithManager(mgr ctrl.Manager) error
- func (i *Image) ValidateCreate() (admission.Warnings, error)
- func (i *Image) ValidateDelete() (admission.Warnings, error)
- func (i *Image) ValidateUpdate(_ runtime.Object) (admission.Warnings, error)
- type ImageList
- type ImageSpec
- type ImageStatus
- type Organization
- func (in *Organization) DeepCopy() *Organization
- func (in *Organization) DeepCopyInto(out *Organization)
- func (in *Organization) DeepCopyObject() runtime.Object
- func (o *Organization) GetCredentialsName() string
- func (o *Organization) GetID() string
- func (o *Organization) GetKind() string
- func (o *Organization) GetName() string
- func (o *Organization) GetPoolManagerFailureReason() string
- func (o *Organization) GetPoolManagerIsRunning() bool
- type OrganizationList
- type OrganizationSpec
- type OrganizationStatus
- type Pool
- func (in *Pool) DeepCopy() *Pool
- func (in *Pool) DeepCopyInto(out *Pool)
- func (in *Pool) DeepCopyObject() runtime.Object
- func (r *Pool) SetupWebhookWithManager(mgr ctrl.Manager) error
- func (r *Pool) ValidateCreate() (admission.Warnings, error)
- func (r *Pool) ValidateDelete() (admission.Warnings, error)
- func (r *Pool) ValidateUpdate(old runtime.Object) (admission.Warnings, error)
- type PoolList
- type PoolSpec
- type PoolStatus
- type Predicate
- type Repository
- func (in *Repository) DeepCopy() *Repository
- func (in *Repository) DeepCopyInto(out *Repository)
- func (in *Repository) DeepCopyObject() runtime.Object
- func (r *Repository) GetCredentialsName() string
- func (r *Repository) GetID() string
- func (r *Repository) GetKind() string
- func (r *Repository) GetName() string
- func (r *Repository) GetPoolManagerFailureReason() string
- func (r *Repository) GetPoolManagerIsRunning() bool
- func (r *Repository) SetupWebhookWithManager(mgr ctrl.Manager) error
- func (r *Repository) ValidateCreate() (admission.Warnings, error)
- func (r *Repository) ValidateDelete() (admission.Warnings, error)
- func (r *Repository) ValidateUpdate(old runtime.Object) (admission.Warnings, error)
- type RepositoryList
- type RepositorySpec
- type RepositoryStatus
- type Runner
- type RunnerList
- type RunnerSpec
- type RunnerStatus
- type SecretRef
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "garm-operator.mercedes-benz.com", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Enterprise ¶
type Enterprise struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EnterpriseSpec `json:"spec,omitempty"`
Status EnterpriseStatus `json:"status,omitempty"`
}
Enterprise is the Schema for the enterprises API
func (*Enterprise) DeepCopy ¶
func (in *Enterprise) DeepCopy() *Enterprise
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Enterprise.
func (*Enterprise) DeepCopyInto ¶
func (in *Enterprise) DeepCopyInto(out *Enterprise)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Enterprise) DeepCopyObject ¶
func (in *Enterprise) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Enterprise) GetCredentialsName ¶
func (e *Enterprise) GetCredentialsName() string
func (*Enterprise) GetID ¶
func (e *Enterprise) GetID() string
func (*Enterprise) GetKind ¶
func (e *Enterprise) GetKind() string
func (*Enterprise) GetName ¶ added in v0.2.1
func (e *Enterprise) GetName() string
func (*Enterprise) GetPoolManagerFailureReason ¶
func (e *Enterprise) GetPoolManagerFailureReason() string
func (*Enterprise) GetPoolManagerIsRunning ¶
func (e *Enterprise) GetPoolManagerIsRunning() bool
type EnterpriseList ¶
type EnterpriseList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Enterprise `json:"items"`
}
EnterpriseList contains a list of Enterprise
func (*EnterpriseList) DeepCopy ¶
func (in *EnterpriseList) DeepCopy() *EnterpriseList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnterpriseList.
func (*EnterpriseList) DeepCopyInto ¶
func (in *EnterpriseList) DeepCopyInto(out *EnterpriseList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnterpriseList) DeepCopyObject ¶
func (in *EnterpriseList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EnterpriseSpec ¶
type EnterpriseSpec struct {
CredentialsName string `json:"credentialsName"`
// WebhookSecretRef represents a secret that should be used for the webhook
WebhookSecretRef SecretRef `json:"webhookSecretRef"`
}
EnterpriseSpec defines the desired state of Enterprise
func (*EnterpriseSpec) DeepCopy ¶
func (in *EnterpriseSpec) DeepCopy() *EnterpriseSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnterpriseSpec.
func (*EnterpriseSpec) DeepCopyInto ¶
func (in *EnterpriseSpec) DeepCopyInto(out *EnterpriseSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnterpriseStatus ¶
type EnterpriseStatus struct {
ID string `json:"id"`
PoolManagerIsRunning bool `json:"poolManagerIsRunning"`
PoolManagerFailureReason string `json:"poolManagerFailureReason,omitempty"`
}
EnterpriseStatus defines the observed state of Enterprise
func (*EnterpriseStatus) DeepCopy ¶
func (in *EnterpriseStatus) DeepCopy() *EnterpriseStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnterpriseStatus.
func (*EnterpriseStatus) DeepCopyInto ¶
func (in *EnterpriseStatus) DeepCopyInto(out *EnterpriseStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitHubScope ¶
type GitHubScope interface {
GetKind() string
GetCredentialsName() string
GetID() string
GetName() string
GetPoolManagerIsRunning() bool
GetPoolManagerFailureReason() string
}
+k8s:deepcopy-gen=false
type GitHubScopeKind ¶
type GitHubScopeKind string
const ( EnterpriseScope GitHubScopeKind = "Enterprise" OrganizationScope GitHubScopeKind = "Organization" RepositoryScope GitHubScopeKind = "Repository" )
func ToGitHubScopeKind ¶
func ToGitHubScopeKind(kind string) (GitHubScopeKind, error)
type Image ¶
type Image struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ImageSpec `json:"spec,omitempty"`
Status ImageStatus `json:"status,omitempty"`
}
Image is the Schema for the images API
func (*Image) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Image.
func (*Image) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Image) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Image) SetupWebhookWithManager ¶
func (*Image) ValidateCreate ¶
ValidateCreate implements webhook.Validator so a webhook will be registered for the type
func (*Image) ValidateDelete ¶
ValidateDelete implements webhook.Validator so a webhook will be registered for the type
type ImageList ¶
type ImageList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Image `json:"items"`
}
ImageList contains a list of Image
func (*ImageList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageList.
func (*ImageList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ImageList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ImageSpec ¶
type ImageSpec struct {
// Tag is the Name of the image in its registry
// e.g.
// - in openstack it can be the image name or id
// - in k8s it can be the docker image name + tag
Tag string `json:"tag,omitempty"`
}
ImageSpec defines the desired state of Image
func (*ImageSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageSpec.
func (*ImageSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ImageStatus ¶
type ImageStatus struct {
}
ImageStatus defines the observed state of Image
func (*ImageStatus) DeepCopy ¶
func (in *ImageStatus) DeepCopy() *ImageStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageStatus.
func (*ImageStatus) DeepCopyInto ¶
func (in *ImageStatus) DeepCopyInto(out *ImageStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Organization ¶
type Organization struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec OrganizationSpec `json:"spec,omitempty"`
Status OrganizationStatus `json:"status,omitempty"`
}
Organization is the Schema for the organizations API
func (*Organization) DeepCopy ¶
func (in *Organization) DeepCopy() *Organization
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Organization.
func (*Organization) DeepCopyInto ¶
func (in *Organization) DeepCopyInto(out *Organization)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Organization) DeepCopyObject ¶
func (in *Organization) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Organization) GetCredentialsName ¶
func (o *Organization) GetCredentialsName() string
func (*Organization) GetID ¶
func (o *Organization) GetID() string
func (*Organization) GetKind ¶
func (o *Organization) GetKind() string
func (*Organization) GetName ¶ added in v0.2.1
func (o *Organization) GetName() string
func (*Organization) GetPoolManagerFailureReason ¶
func (o *Organization) GetPoolManagerFailureReason() string
func (*Organization) GetPoolManagerIsRunning ¶
func (o *Organization) GetPoolManagerIsRunning() bool
type OrganizationList ¶
type OrganizationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Organization `json:"items"`
}
OrganizationList contains a list of Organization
func (*OrganizationList) DeepCopy ¶
func (in *OrganizationList) DeepCopy() *OrganizationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OrganizationList.
func (*OrganizationList) DeepCopyInto ¶
func (in *OrganizationList) DeepCopyInto(out *OrganizationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*OrganizationList) DeepCopyObject ¶
func (in *OrganizationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type OrganizationSpec ¶
type OrganizationSpec struct {
CredentialsName string `json:"credentialsName"`
// WebhookSecretRef represents a secret that should be used for the webhook
WebhookSecretRef SecretRef `json:"webhookSecretRef"`
}
OrganizationSpec defines the desired state of Organization
func (*OrganizationSpec) DeepCopy ¶
func (in *OrganizationSpec) DeepCopy() *OrganizationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OrganizationSpec.
func (*OrganizationSpec) DeepCopyInto ¶
func (in *OrganizationSpec) DeepCopyInto(out *OrganizationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OrganizationStatus ¶
type OrganizationStatus struct {
ID string `json:"id"`
PoolManagerIsRunning bool `json:"poolManagerIsRunning"`
PoolManagerFailureReason string `json:"poolManagerFailureReason,omitempty"`
}
OrganizationStatus defines the observed state of Organization
func (*OrganizationStatus) DeepCopy ¶
func (in *OrganizationStatus) DeepCopy() *OrganizationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OrganizationStatus.
func (*OrganizationStatus) DeepCopyInto ¶
func (in *OrganizationStatus) DeepCopyInto(out *OrganizationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Pool ¶
type Pool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PoolSpec `json:"spec,omitempty"`
Status PoolStatus `json:"status,omitempty"`
}
Pool is the Schema for the pools API
func (*Pool) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Pool.
func (*Pool) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Pool) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Pool) SetupWebhookWithManager ¶
func (*Pool) ValidateCreate ¶
ValidateCreate implements webhook.Validator so a webhook will be registered for the type
func (*Pool) ValidateDelete ¶
ValidateDelete implements webhook.Validator so a webhook will be registered for the type
type PoolList ¶
type PoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Pool `json:"items"`
}
PoolList contains a list of Pool
func (*PoolList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolList.
func (*PoolList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PoolList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PoolList) FilterByFields ¶
type PoolSpec ¶
type PoolSpec struct {
// Defines in which Scope Runners a registered. Has a reference to either an Enterprise, Org or Repo CRD
GitHubScopeRef corev1.TypedLocalObjectReference `json:"githubScopeRef"`
ProviderName string `json:"providerName"`
MaxRunners uint `json:"maxRunners"`
// +kubebuilder:default=0
MinIdleRunners uint `json:"minIdleRunners"`
Flavor string `json:"flavor"`
OSType commonParams.OSType `json:"osType"`
OSArch commonParams.OSArch `json:"osArch"`
Tags []string `json:"tags"`
Enabled bool `json:"enabled"`
RunnerBootstrapTimeout uint `json:"runnerBootstrapTimeout"`
// The name of the image resource, this image resource must exists in the same namespace as the pool
ImageName string `json:"imageName"`
// +optional
ExtraSpecs string `json:"extraSpecs"`
// +optional
GitHubRunnerGroup string `json:"githubRunnerGroup"`
// +optional
RunnerPrefix string `json:"runnerPrefix"`
}
+kubebuilder:validation:Required +kubebuilder:validation:XValidation:rule="self.minIdleRunners <= self.maxRunners",message="minIdleRunners must be less than or equal to maxRunners"
func (*PoolSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolSpec.
func (*PoolSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PoolStatus ¶
type PoolStatus struct {
ID string `json:"id"`
LongRunningIdleRunners uint `json:"longRunningIdleRunners"`
Selector string `json:"selector"`
LastSyncError string `json:"lastSyncError,omitempty"`
}
PoolStatus defines the observed state of Pool
func (*PoolStatus) DeepCopy ¶
func (in *PoolStatus) DeepCopy() *PoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolStatus.
func (*PoolStatus) DeepCopyInto ¶
func (in *PoolStatus) DeepCopyInto(out *PoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Predicate ¶
+k8s:deepcopy-gen=false
func MatchesFlavour ¶
func MatchesGitHubScope ¶
func MatchesImage ¶
func MatchesProvider ¶
type Repository ¶
type Repository struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RepositorySpec `json:"spec,omitempty"`
Status RepositoryStatus `json:"status,omitempty"`
}
Repository is the Schema for the repositories API
func (*Repository) DeepCopy ¶
func (in *Repository) DeepCopy() *Repository
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Repository.
func (*Repository) DeepCopyInto ¶
func (in *Repository) DeepCopyInto(out *Repository)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Repository) DeepCopyObject ¶
func (in *Repository) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Repository) GetCredentialsName ¶
func (r *Repository) GetCredentialsName() string
func (*Repository) GetID ¶
func (r *Repository) GetID() string
func (*Repository) GetKind ¶
func (r *Repository) GetKind() string
func (*Repository) GetName ¶ added in v0.2.1
func (r *Repository) GetName() string
func (*Repository) GetPoolManagerFailureReason ¶
func (r *Repository) GetPoolManagerFailureReason() string
func (*Repository) GetPoolManagerIsRunning ¶
func (r *Repository) GetPoolManagerIsRunning() bool
func (*Repository) SetupWebhookWithManager ¶
func (r *Repository) SetupWebhookWithManager(mgr ctrl.Manager) error
func (*Repository) ValidateCreate ¶
func (r *Repository) ValidateCreate() (admission.Warnings, error)
ValidateCreate implements webhook.Validator so a webhook will be registered for the type
func (*Repository) ValidateDelete ¶
func (r *Repository) ValidateDelete() (admission.Warnings, error)
ValidateDelete implements webhook.Validator so a webhook will be registered for the type
func (*Repository) ValidateUpdate ¶
ValidateUpdate implements webhook.Validator so a webhook will be registered for the type
type RepositoryList ¶
type RepositoryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Repository `json:"items"`
}
RepositoryList contains a list of Repository
func (*RepositoryList) DeepCopy ¶
func (in *RepositoryList) DeepCopy() *RepositoryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RepositoryList.
func (*RepositoryList) DeepCopyInto ¶
func (in *RepositoryList) DeepCopyInto(out *RepositoryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RepositoryList) DeepCopyObject ¶
func (in *RepositoryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RepositorySpec ¶
type RepositorySpec struct {
CredentialsName string `json:"credentialsName"`
Owner string `json:"owner"`
// WebhookSecretRef represents a secret that should be used for the webhook
WebhookSecretRef SecretRef `json:"webhookSecretRef"`
}
RepositorySpec defines the desired state of Repository
func (*RepositorySpec) DeepCopy ¶
func (in *RepositorySpec) DeepCopy() *RepositorySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RepositorySpec.
func (*RepositorySpec) DeepCopyInto ¶
func (in *RepositorySpec) DeepCopyInto(out *RepositorySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RepositoryStatus ¶
type RepositoryStatus struct {
ID string `json:"id"`
PoolManagerIsRunning bool `json:"poolManagerIsRunning"`
PoolManagerFailureReason string `json:"poolManagerFailureReason,omitempty"`
}
RepositoryStatus defines the observed state of Repository
func (*RepositoryStatus) DeepCopy ¶
func (in *RepositoryStatus) DeepCopy() *RepositoryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RepositoryStatus.
func (*RepositoryStatus) DeepCopyInto ¶
func (in *RepositoryStatus) DeepCopyInto(out *RepositoryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Runner ¶ added in v0.2.0
type Runner struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RunnerSpec `json:"spec,omitempty"`
Status RunnerStatus `json:"status,omitempty"`
}
Runner is the Schema for the runners API
func (*Runner) DeepCopy ¶ added in v0.2.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Runner.
func (*Runner) DeepCopyInto ¶ added in v0.2.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Runner) DeepCopyObject ¶ added in v0.2.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RunnerList ¶ added in v0.2.0
type RunnerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Runner `json:"items"`
}
RunnerList contains a list of Runner
func (*RunnerList) DeepCopy ¶ added in v0.2.0
func (in *RunnerList) DeepCopy() *RunnerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RunnerList.
func (*RunnerList) DeepCopyInto ¶ added in v0.2.0
func (in *RunnerList) DeepCopyInto(out *RunnerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RunnerList) DeepCopyObject ¶ added in v0.2.0
func (in *RunnerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RunnerSpec ¶ added in v0.2.0
type RunnerSpec struct{}
RunnerSpec defines the desired state of Runner
func (*RunnerSpec) DeepCopy ¶ added in v0.2.0
func (in *RunnerSpec) DeepCopy() *RunnerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RunnerSpec.
func (*RunnerSpec) DeepCopyInto ¶ added in v0.2.0
func (in *RunnerSpec) DeepCopyInto(out *RunnerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RunnerStatus ¶ added in v0.2.0
type RunnerStatus struct {
// ID is the database ID of this instance.
ID string `json:"id,omitempty"`
// PeoviderID is the unique ID the provider associated
// with the compute instance. We use this to identify the
// instance in the provider.
ProviderID string `json:"providerId,omitempty"`
// AgentID is the github runner agent ID.
AgentID int64 `json:"agentId"`
// Name is the name associated with an instance. Depending on
// the provider, this may or may not be useful in the context of
// the provider, but we can use it internally to identify the
// instance.
Name string `json:"name,omitempty"`
// OSType is the operating system type. For now, only Linux and
// Windows are supported.
OSType commonParams.OSType `json:"osType,omitempty"`
// OSName is the name of the OS. Eg: ubuntu, centos, etc.
OSName string `json:"osName,omitempty"`
// OSVersion is the version of the operating system.
OSVersion string `json:"osVersion,omitempty"`
// OSArch is the operating system architecture.
OSArch commonParams.OSArch `json:"osArch,omitempty"`
// Addresses is a list of IP addresses the provider reports
// for this instance.
Addresses []commonParams.Address `json:"addresses,omitempty"`
// Status is the status of the instance inside the provider (eg: running, stopped, etc)
Status commonParams.InstanceStatus `json:"status,omitempty"`
// RunnerStatus is the github runner status as it appears on GitHub.
InstanceStatus params.RunnerStatus `json:"instanceStatus,omitempty"`
// PoolID is the ID of the garm pool to which a runner belongs.
PoolID string `json:"poolId,omitempty"`
// ProviderFault holds any error messages captured from the IaaS provider that is
// responsible for managing the lifecycle of the runner.
ProviderFault string `json:"providerFault,omitempty"`
// GithubRunnerGroup is the github runner group to which the runner belongs.
// The runner group must be created by someone with access to the enterprise.
GitHubRunnerGroup string `json:"githubRunnerGroup"`
}
RunnerStatus defines the observed state of Runner
func (*RunnerStatus) DeepCopy ¶ added in v0.2.0
func (in *RunnerStatus) DeepCopy() *RunnerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RunnerStatus.
func (*RunnerStatus) DeepCopyInto ¶ added in v0.2.0
func (in *RunnerStatus) DeepCopyInto(out *RunnerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretRef ¶
type SecretRef struct {
// Name of the kubernetes secret to use
Name string `json:"name"`
// Key is the key in the secret's data map for this value
Key string `json:"key"`
}
func (*SecretRef) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretRef.
func (*SecretRef) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.